| Title: | Access the Streetmix API |
|---|---|
| Description: | Support access to the Streetmix API and share data on Streetmix illustrations and components for analysis or reuse (consistent with license requirements). |
| Authors: | Eli Pousson [aut, cre] (ORCID: <https://orcid.org/0000-0001-8280-1706>) |
| Maintainer: | Eli Pousson <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-23 06:17:02 UTC |
| Source: | https://github.com/elipousson/streetmixr |
Last updated: 2024-11-10
componentscomponents
A length 5 nested list with specifications for lanes, markings, objects, vehicles, and effects.
https://github.com/streetmix/streetmix/raw/refs/heads/main/client/src/segments/components.json
Get data on a Streetmix street
get_street( url = NULL, user_id = NULL, street_id = NULL, count = NULL, return = "data" )get_street( url = NULL, user_id = NULL, street_id = NULL, count = NULL, return = "data" )
url |
Streetmix url to get data on |
user_id |
Streetmix user account ID |
street_id |
Streetmix street ID |
count |
Count of streets to return |
return |
Type of data to return based on url: "data", "street",
"location", or "segments". If |
Last updated: 2024-11-10
Data frame with links to SVG files with StreetMix illustrations https://github.com/streetmix/illustrations
Illustrations available under an attribution-share alike license https://github.com/streetmix/illustrations/blob/main/LICENSE
For design guidelines and colors see the illustration guide https://docs.streetmix.net/contributing/illustrations/design-principles
illustrationsillustrations
A data frame with 273 rows and 8 variables:
reporepository
nameillustration name
urlSVG file url
categorycategory/folder
sidefacing side (left or right)
directiondirection of movement (inbound or outbound)
orientationorientation (parallel, perpendicular, sideways, or angled)
width_typebuilding width type (narrow or wide)
https://github.com/streetmix/illustrations
Last updated: 2024-11-10
peoplepeople
A data frame with 36 rows and 5 variables:
idimage id
widthimage width
nameimage name
disallowFirstlogical
weightinteger
https://github.com/streetmix/streetmix/raw/refs/heads/main/client/src/segments/people.json